==> haskell-success-0.2.6-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: success
version: 0.2.6
id: success-0.2.6-8y4n4JmG7zC4QhlWKeqzek
key: success-0.2.6-8y4n4JmG7zC4QhlWKeqzek
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/success
synopsis: A version of Either specialised for encoding of success or failure
description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.
category: Data, Failure
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Success.Pure Success.Impure
abi: ec08543b3829c26e765750ecd9e3d3a6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/success-0.2.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/success-0.2.6
data-dir: /usr/share/i386-linux-ghc-8.0.1/success-0.2.6
hs-libraries: HSsuccess-0.2.6-8y4n4JmG7zC4QhlWKeqzek
depends:
    base-4.9.0.0 monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-success/html/success.haddock
haddock-html: /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-success-0.2.6-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: success
version: 0.2.6
id: success-0.2.6-5u1iDo7XBCzJprHpKMGp9b
key: success-0.2.6-5u1iDo7XBCzJprHpKMGp9b
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/success
synopsis: A version of Either specialised for encoding of success or failure
description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.
category: Data, Failure
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Success.Pure Success.Impure
abi: bc251c2e8ec8fbb38e24c2825f99c584
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/success-0.2.6
library-dirs: /usr/lib/ghc-8.0.2/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/success-0.2.6
hs-libraries: HSsuccess-0.2.6-5u1iDo7XBCzJprHpKMGp9b
depends:
    base-4.9.1.0 monad-control-1.0.2.0-10S0ywqdsCPHnUTlxJLEct
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/haskell-success/html/success.haddock
haddock-html: /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
